==> twilio-3.4.0.tar.gz: twilio-3.4.0/twilio/rest/resources/__init__.py <==
import re
import datetime
import logging
import twilio
from twilio import TwilioException, TwilioRestException
from urllib import urlencode
from urlparse import urlparse

from twilio.rest.resources.imports import (
    parse_qs, json, httplib2
)

from twilio.rest.resources.util import (
    transform_params, format_name, parse_date, convert_boolean, convert_case,
    convert_keys, normalize_dates
)
from twilio.rest.resources.base import (
    Response, Resource, InstanceResource, ListResource,
    make_request, make_twilio_request
)
from twilio.rest.resources.phone_numbers import (
    AvailablePhoneNumber, AvailablePhoneNumbers, PhoneNumber, PhoneNumbers
)
from twilio.rest.resources.recordings import (
    Recording, Recordings, Transcription, Transcriptions
)
from twilio.rest.resources.notifications import (
    Notification, Notifications
)
from twilio.rest.resources.connect_apps import (
    ConnectApp, ConnectApps, AuthorizedConnectApp, AuthorizedConnectApps
)
from twilio.rest.resources.calls import Call, Calls
from twilio.rest.resources.caller_ids import CallerIds
from twilio.rest.resources.sandboxes import Sandbox, Sandboxes
from twilio.rest.resources.sms_messages import (
    Sms, SmsMessage, SmsMessages, ShortCode, ShortCodes)
from twilio.rest.resources.conferences import (
    Participant, Participants, Conference, Conferences
)
from twilio.rest.resources.queues import (
    Member, Members, Queue, Queues,
)
from twilio.rest.resources.applications import (
    Application, Applications
)
from twilio.rest.resources.accounts import Account, Accounts

==> twilio-3.5.0.tar.gz: twilio-3.5.0/twilio/rest/resources/__init__.py <==
import re
import datetime
import logging
import twilio
from twilio import TwilioException, TwilioRestException

from twilio.rest.resources.imports import (
    parse_qs, json, httplib2
)

from twilio.rest.resources.util import (
    transform_params, format_name, parse_date, convert_boolean, convert_case,
    convert_keys, normalize_dates
)
from twilio.rest.resources.base import (
    Response, Resource, InstanceResource, ListResource,
    make_request, make_twilio_request
)
from twilio.rest.resources.phone_numbers import (
    AvailablePhoneNumber, AvailablePhoneNumbers, PhoneNumber, PhoneNumbers
)
from twilio.rest.resources.recordings import (
    Recording, Recordings, Transcription, Transcriptions
)
from twilio.rest.resources.notifications import (
    Notification, Notifications
)
from twilio.rest.resources.connect_apps import (
    ConnectApp, ConnectApps, AuthorizedConnectApp, AuthorizedConnectApps
)
from twilio.rest.resources.calls import Call, Calls
from twilio.rest.resources.caller_ids import CallerIds, CallerId
from twilio.rest.resources.sandboxes import Sandbox, Sandboxes
from twilio.rest.resources.sms_messages import (
    Sms, SmsMessage, SmsMessages, ShortCode, ShortCodes)
from twilio.rest.resources.conferences import (
    Participant, Participants, Conference, Conferences
)
from twilio.rest.resources.queues import (
    Member, Members, Queue, Queues,
)
from twilio.rest.resources.applications import (
    Application, Applications
)
from twilio.rest.resources.accounts import Account, Accounts

from twilio.rest.resources.usage import Usage
